#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import tkinter as tk
import tkinter.font as tkf
import tkinter.ttk as ttk

white="#ffffff"
blue="#0063B1"
lightBlue="#1972B9"
ultraLightBlue="#BAD4EA"
gray="#1F1F1F"
lightGray="#353535"

root = tk.Tk()
root.title("Menu")

icons = tkf.Font(family='Segoe MDL2 Assets', size=13, weight='normal')
iconsBig = tkf.Font(family='Segoe MDL2 Assets', size=16, weight='normal')
fontNormal = tkf.Font(family='Segoe UI', size=11, weight='normal', )
fontLight = tkf.Font(family='Segoe UI Light', size=11, weight='normal', )
fontSemibold = tkf.Font(family='Segoe UI Semibold', size=11, weight='normal', )
fontBold = tkf.Font(family='Segoe UI Black', size=11, weight='normal')

class MenuButton(tk.Frame):
  def __init__(self, frame, icon, text, variable, value, size=12):
    tk.Frame.__init__(self, frame, bg=gray)

    self.variable = variable
    self.variable.trace_add("write", self._notify)
    self.value = value
     
    self.mark = tk.Label(self, font=icons, bg=blue if self.is_active() else gray)
    self.mark.pack(side=tk.LEFT, anchor=tk.W)

    self.icon = tk.Label(self, text=icon, font=icons, bg=gray, fg=white)
    self.icon.pack(side=tk.LEFT, anchor=tk.W, ipadx=size, ipady=size)
    
    self.text = tk.Label(self, text=text, font=fontNormal, bg=gray, fg=white)
    self.text.pack(side=tk.LEFT, anchor=tk.W, ipadx=0, ipady=size)

    self.bind("<Enter>", self._enter)
    self.bind("<Leave>", self._leave)
    self.bind("<Button-1>", self._select)
    self.mark.bind("<Button-1>", self._select)
    self.icon.bind("<Button-1>", self._select)
    self.text.bind("<Button-1>", self._select)
  
  
  def is_active(self):
    return self.variable.get() == self.value
    
  def _enter(self, event, color=lightGray):        
    self.configure(bg=color)
    self.mark.configure(bg=blue if self.is_active() else color)
    self.icon.configure(bg=color)
    self.text.configure(bg=color)
    
  def _leave(self, event, color=gray):        
    self.configure(bg=color)    
    self.mark.configure(bg=blue if self.is_active() else color)
    self.icon.configure(bg=color)
    self.text.configure(bg=color)
    
  def _select(self, event, color=gray):
    self.variable.set(self.value)
    self._enter(event)
    
  def _notify(self, name, msg, mode):
    self._leave(None) 


# left menu frame
frmLeft = tk.Frame(root, bg=gray)
frmLeft.pack(side=tk.LEFT, fill=tk.Y)

# menu buttons
m = tk.IntVar()
m.set(1)

btnMenu = MenuButton(frmLeft, icon="\ue700", text="", variable=m, value=1);
btnMenu.pack(side=tk.TOP, anchor=tk.W, fill=tk.X)

btnHome = MenuButton(frmLeft, icon="\ue80f", text="Home", variable=m, value=2);
btnHome.pack(side=tk.TOP, anchor=tk.W, fill=tk.X)

btnHistory = MenuButton(frmLeft, icon="\ue7bc", text="History", variable=m, value=3);
btnHistory.pack(side=tk.TOP, anchor=tk.W, fill=tk.X)

btnFavorite = MenuButton(frmLeft, icon="\ue728", text="Favorite", variable=m, value=4);
btnFavorite.pack(side=tk.TOP, anchor=tk.W, fill=tk.X)
# end of menu buttons

root.mainloop()
